@@ -258,4 +258,15 @@ impl DittoAuthenticator {
             s
         })
     }
+
+    /// Log out of Ditto
+    /// Shutdown all replication sessions and remove any cached authentication
+    /// credentials. This does *not* remove the local data store.
+    pub fn logout(&self) -> Result<(), DittoError> {
+        let status = unsafe { ffi_sdk::ditto_auth_client_logout(&*self.auth_client) };
+        match status {
+            0 => Ok(()),
+            _ => Err(DittoError::from_ffi(ErrorKind::Authentication)),
+        }
+    }
 }
