@@ -25,7 +25,7 @@ pub fn test_license_from_file<P: AsRef<Path>>(path: P) -> std::io::Result<String
 pub fn get_ditto() -> Result<Ditto, DittoError> {
     let mut ditto = Ditto::builder()
         .with_temp_dir()
-        .with_identity(|ditto_root| identity::Development::random(ditto_root))?
+        .with_identity(|ditto_root| identity::OfflinePlayground::random(ditto_root))?
         .with_minimum_log_level(CLogLevel::Info)
         .build()?;
     ditto.set_license_from_env("DITTO_LICENSE")?;
@@ -36,7 +36,7 @@ pub fn get_ditto() -> Result<Ditto, DittoError> {
 pub fn get_inactive_ditto() -> Result<Ditto, DittoError> {
     let ditto = Ditto::builder()
         .with_temp_dir()
-        .with_identity(|ditto_root| identity::Development::random(ditto_root))?
+        .with_identity(|ditto_root| identity::OfflinePlayground::random(ditto_root))?
         .with_minimum_log_level(CLogLevel::Info)
         .build()?;
     Ok(ditto)
